@@ -1,9 +1,28 @@
 import json
+from django.utils import six
 
 from django.views.generic import View
 from django.utils.safestring import mark_safe
 from django.shortcuts import render_to_response, RequestContext
 from django.core.exceptions import PermissionDenied
+try:
+    from django.utils.module_loading import import_string
+except ImportError:
+    def import_string(dotted_path):
+        from django.utils.importlib import import_module
+        from django.core.exceptions import ImproperlyConfigured
+        module, attr = dotted_path.rsplit('.', 1)
+        try:
+            mod = import_module(module)
+        except ImportError as e:
+            raise ImproperlyConfigured('Error importing module %s: "%s"' %
+                                       (module, e))
+        try:
+            view = getattr(mod, attr)
+        except AttributeError:
+            raise ImproperlyConfigured('Module "%s" does not define a "%s".'
+                                       % (module, attr))
+        return view
 
 from rest_framework.views import Response
 from rest_framework_swagger.urlparser import UrlParser
@@ -19,7 +38,7 @@ class SwaggerUIView(View):
     def get(self, request, *args, **kwargs):
 
         if not self.has_permission(request):
-            raise PermissionDenied()
+            return self.handle_permission_denied(request)
 
         template_name = "rest_framework_swagger/index.html"
         data = {
@@ -27,7 +46,7 @@ class SwaggerUIView(View):
                 'discovery_url': "%sapi-docs/" % request.build_absolute_uri(),
                 'api_key': SWAGGER_SETTINGS.get('api_key', ''),
                 'enabled_methods': mark_safe(
-                    json.dumps( SWAGGER_SETTINGS.get('enabled_methods')))
+                    json.dumps(SWAGGER_SETTINGS.get('enabled_methods')))
             }
         }
         response = render_to_response(template_name, RequestContext(request, data))
@@ -43,6 +62,16 @@ class SwaggerUIView(View):
 
         return True
 
+    def handle_permission_denied(self, request):
+        permission_denied_handler = SWAGGER_SETTINGS.get('permission_denied_handler')
+        if isinstance(permission_denied_handler, six.string_types):
+            permission_denied_handler = import_string(permission_denied_handler)
+
+        if permission_denied_handler:
+            return permission_denied_handler(request)
+        else:
+            raise PermissionDenied()
+
 
 class SwaggerResourcesView(APIDocView):
 
@@ -81,9 +110,12 @@ class SwaggerApiView(APIDocView):
         generator = DocumentationGenerator()
 
         return Response({
+            'apiVersion': SWAGGER_SETTINGS.get('api_version', ''),
+            'swaggerVersion': '1.2',
+            'basePath': self.api_full_uri.rstrip('/'),
+            'resourcePath': '/' + path,
             'apis': generator.generate(apis),
             'models': generator.get_models(apis),
-            'basePath': self.api_full_uri.rstrip('/'),
         })
 
     def get_api_for_resource(self, filter_path):
